aboutsummaryrefslogtreecommitdiff
path: root/filters/syntax-highlighting.py
diff options
from:
to:
context:
space:
mode:
authorGravatar Saya Andy <saya.andy@posteo.com> 2026-07-31 11:56:31 +0700
committerGravatar Saya Andy <saya.andy@posteo.com> 2026-07-31 11:56:31 +0700
commit793860dbd6df42d5bbf05542f2292a1c6d30fc76 (patch)
tree7f25119d300ea44371bd9d25207e1228cf488e0d /filters/syntax-highlighting.py
parent306fafc1d1d19c51d7ac24479f49c76272934ce5 (diff)
downloadcgitext-1.3.1+10.tar.gz
cgitext-1.3.1+10.zip
style: replace hardcoded color codes with css variablesv1.3.1+10
In order to: a) do custom theme simpler by just replacing necessary vars, b) apply this theme to filters as well; the main cgit.css file now defines CSS vars and uses them in color parameters.
Diffstat (limited to 'filters/syntax-highlighting.py')
-rwxr-xr-xfilters/syntax-highlighting.py45
1 files changed, 42 insertions, 3 deletions
diff --git a/filters/syntax-highlighting.py b/filters/syntax-highlighting.py
index e912594..d757e2d 100755
--- a/filters/syntax-highlighting.py
+++ b/filters/syntax-highlighting.py
@@ -30,11 +30,50 @@ from pygments.lexers import guess_lexer_for_filename
from pygments.formatters import HtmlFormatter
+# Pygments' token classes, mapped onto the --syn-* custom properties that
+# cgit.css defines. The fallbacks are the palette those properties default to,
+# so that the output stays readable under a stylesheet without them.
+SYNTAX_COLORS = (
+ (('k', 'kc', 'kd', 'kn', 'kr'), '--syn-keyword', '#000',
+ 'font-weight: bold'),
+ (('kp',), '--syn-keyword', '#000', None),
+ (('kt',), '--syn-type', '#010181', None),
+ (('nc', 'nf', 'nn', 'ne'), '--syn-keyword-alt', '#0057ae', None),
+ (('s', 'sa', 'sb', 'sc', 'dl', 'sd', 's2', 'sh', 'sx', 'sr', 's1', 'ss'),
+ '--syn-string', '#bf0303', None),
+ (('se',), '--syn-escape', '#f0f', None),
+ (('si',), '--syn-interpolation', '#0057ae', None),
+ (('c', 'ch', 'cm', 'c1', 'cs'), '--syn-comment', '#838183',
+ 'font-style: italic'),
+ (('cp', 'cpf'), '--syn-preproc', '#008200', None),
+ (('m', 'mb', 'mf', 'mh', 'mi', 'mo', 'il'), '--syn-number', '#b07e00',
+ None),
+ (('o', 'ow', 'p'), '--syn-operator', '#000', None),
+ (('err',), '--syn-error', '#bf0303', None),
+ (('gd',), '--red', 'red', None),
+ (('gi',), '--green', 'green', None),
+ (('lineno', 'linenos'), '--syn-linenum', '#555', None),
+)
+
+
+def style_defs(prefix='.highlight'):
+ rules = []
+ for classes, prop, fallback, extra in SYNTAX_COLORS:
+ selector = ', '.join('%s .%s' % (prefix, c) for c in classes)
+ decls = 'color: var(%s, %s)' % (prop, fallback)
+ if extra:
+ decls += '; ' + extra
+ rules.append('%s { %s }' % (selector, decls))
+ rules.append('%s .hll { background-color: var(--syn-mark-bg, #ffb) }'
+ % prefix)
+ return '\n'.join(rules) + '\n'
+
+
sys.stdin = io.TextIOWrapper(sys.stdin.buffer, encoding='utf-8', errors='replace')
sys.stdout = io.TextIOWrapper(sys.stdout.buffer, encoding='utf-8', errors='replace')
data = sys.stdin.read()
filename = sys.argv[1]
-formatter = HtmlFormatter(style='pastie', nobackground=True)
+formatter = HtmlFormatter(nobackground=True)
try:
lexer = guess_lexer_for_filename(filename, data)
@@ -48,8 +87,8 @@ except TypeError:
lexer = TextLexer()
# highlight! :-)
# printout pygments' css definitions as well
sys.stdout.write('<style>')
-sys.stdout.write(formatter.get_style_defs('.highlight'))
+sys.stdout.write(style_defs('.highlight'))
sys.stdout.write('</style>')
sys.stdout.write(highlight(data, lexer, formatter, outfile=None))
@@ -48,8 +87,8 @@ except TypeError:
lexer = TextLexer()
# highlight! :-)
-# printout pygments' css definitions as well
+# printout the css definitions for pygments' token classes as well
sys.stdout.write('<style>')